RUNDEF Section11

/*
CREATION OF A PERMANENT VARIABLE
Household head has partner

Program description:
This program establishes if the head of the household has a partner,
either a spouse or a person in consens union.
The new variable has two categories: 0 if the head has no partner, or 1 if
the head has a partner.
Verification of results is obtained by two tables.
*/

DEFINE HOUSIN.HASSPOUSE AS COUNT PERSON
  FOR PERSON.RELAT = 2
  RANGE 0-1
  
DEFINE HOUSIN.HASCMLAW AS COUNT PERSON
  FOR PERSON.RELAT = 3
  TYPE INTEGER
  RANGE 0-1
  
DEFINE HOUSIN.HASPARTNER
  AS ( HOUSIN.HASSPOUSE <> 0 ) OR ( HOUSIN.HASCMLAW <> 0 )
  VARLABEL "Head has a Partner or Not"
  TYPE BOOL
  SAVE "HOUSIN_HEADHASPATNER.rbf" OVERWRITE

TABLE VERIF1 AS FREQUENCY OF HOUSIN.HASCMLAW BY HOUSIN.HASSPOUSE
TABLE VERIF2 AS FREQUENCY OF HOUSIN.HASPARTNER

/*
Programming notes:
1. The program uses two intermediate variables (HOUSIN.HASSPOUSE
   and HOUSIN.HASCMLAW) that respectively count the number
   of individuals with variable PERSON.RELAT = 2 (count of spouses)
   and PERSON.RELAT = 3 (count of consens union partners). 
2. The final variable is obtained using a logical expression
   (HOUSIN.HASSPOUSE <> 0) OR (HOUSIN.HASCMLAW <> 0)
   that is false (0) when no spouse or consens union partner are
   part of the household.

Results:
Table Verif1
HASCMLAW   HASSPOUSE		
              0     1     Total
 0         6372  6910     13282
 1          637     -       637
 Total     7009  6910     13919

Table Verif2
Categories     Counts      %
 False           6372   45,8
 True            7547   54,2
 Total          13919  100,0

Comments:
1. The first table shows that 6372 households are single headed (no partner).
   This figure is confirmed by the second table (category False of
   the variable), showing also the percentage of single headeds (45,8%).
2. Again, this figure is misleading, since we did not take into account
   the number of households with ho heads. By using a filter in
   the second table to select households with heads we will get a different result.
   The filter could be the sex of the household created in Section10.
   So, the second table should be
   TABLE VERIF3 AS FREQUENCY OF HOUSIN.HASPARTNER
       for HOUSIN.SEXHEAD = 1 or HOUSIN.SEXHEAD = 2
3. Using this filter the percentage of single headed households drops to 33,7%.
4. Do not forget to save the dictionary after executing the program.
*/