RUNDEF Section12

/*
DERIVING A VARIABLE USING THE SWITCH FUNCTION
Type of household 

Program description:
The use of SWITCH function is recommended when the definition of a variable
is based on several other variables.
While more complicated to implement, this technique prevents much more easily
the introduction of semantic errors.
The SWITCH function may be seen as the implementation of a decision tree.

The following example illustrates the classification of a household based
on the number of children in the household, the sex of the head and
the existence or not of a spouse or consens union of the head.
It implements the following decision tree:

The household is not single headed
    The household does not include children     Type 1
    The household includes children             Type 2
The household is single headed
    The head is a male		
        The household does not include children Type 3
        The household includes children         Type 4
    The head is female
        The household does not include children Type 5
        The household includes children         Type 6
 
Please, note that this program uses derived variables permanently saved
in the database by previous sections.
*/

DEFINE HOUSIN.HHTYPE AS SWITCH
      INCASE HOUSIN.HASPARTNER = 1 AND HOUSIN.NCHILDREN = 0
        ASSIGN 1
      INCASE HOUSIN.HASPARTNER = 1 AND HOUSIN.NCHILDREN > 0
        ASSIGN 2
      INCASE HOUSIN.HASPARTNER = 0 AND HOUSIN.SEXHEAD = 1 AND HOUSIN.NCHILDREN = 0
        ASSIGN 3
      INCASE HOUSIN.HASPARTNER = 0 AND HOUSIN.SEXHEAD = 2 AND HOUSIN.NCHILDREN = 0
        ASSIGN 5
      INCASE HOUSIN.HASPARTNER = 0 AND HOUSIN.SEXHEAD = 1 AND HOUSIN.NCHILDREN > 0
        ASSIGN 4
      INCASE HOUSIN.HASPARTNER = 0 AND HOUSIN.SEXHEAD = 2 AND HOUSIN.NCHILDREN > 0
        ASSIGN 6
    VARLABEL "Head Partner"
    VALUELABELS
    2 "Head and Partner with Children"
    3 "Single Headed by Male no Children"
    4 "Single Headed by Male with Children"
    5 "Single Headed by Female no Children"
    6 "Single Headed by Female with Children"
    RANGE 1-6
    SAVE "HOUSIN_HOUSEHOLDTYPE.rbf" OVERWRITE

TABLE VERIF AS FREQUENCY OF HOUSIN.HHTYPE

/*
Programming notes:
1. It executes in pairs of INCASE and ASSIGN instructions.
   The INCASE defines the condition for the next ASSIGN to be executed.
2. The ASSIGN could have been written in the same line as the previous INCASE.
3. As in the RECODE type of defining, the SWITCH acepts an ELSE instruction,
   to cope with all the cases not stated by previous INCASEs.
4. As in the RECODE, values that do not fall into any INCASE expressions,
   will stay the same, provided there is no ELSE expression.
   
Results:
    Categories                            Counts        %
     Head and Partner without Children      2459     21,6
     Head and Partner with Children         5088     44,7
     Single Headed by Male no Children      1504     13,2
     Single Headed by Male with Children     104      9,1
     Single Headed by Female no Children    1429     12,6
     Single Headed by Female with Children   791      7,0
     Total                                 11375    100,0

Missing :                                   2544	

Comments:
1. Households having no heads will receive a Missing value.
2. Do not forget to save the dictionary after executing the program.
*/
