RUNDEF Section18

/*
CALCULATING A SEX RATIO BY AREA

Program description:
This program calculates the sex ratio per area.
The sex ratio is established as the ratio of the number of males divided
by the number of females in each area.
*/

DEFINE COUNTY.NMALES
  AS COUNT PERSON
  FOR PERSON.SEX = 1
  VARLABEL "# of Males"
  
DEFINE COUNTY.NFEMALES
  AS COUNT PERSON
  FOR PERSON.SEX = 2
  VARLABEL "# of Females"

DEFINE COUNTY.SEXRATIO AS COUNTY.NMALES / COUNTY.NFEMALES
  TYPE REAL
  FOR COUNTY.NFEMALES > 0
  VARLABEL "Sex Ratio per County"
  DECIMALS 2
  
TABLE VERIF AS AREALIST OF COUNTY, COUNTY.NCOUNTY,
  COUNTY.NMALES, COUNTY.NFEMALES, COUNTY.SEXRATIO
  TITLE "Sex Ratio in New Miranda"
  DECIMALS 2

/*
Programming notes:
1. The clause FOR COUNTY.NFEMALES > 0 guarantees no division by zero
   is to occur.
   Even if the precaution is not necessary in this obvious case,
   it is a good practice to include such a clause in every division.
2. When a variable is included in an AREALIST, no range needs to be specified
   in the variable definition.
3. A title clause can be used to identify the list.

Results:
Code  County Name   # of Males   # of Females   Sex Ratio per County
5     Santa Maria        10767          10961                   0,98
6     Santiago            4931           4038                   1,22
7     Bolivar             7300           6981                   1,05
8     Marbella            2004           1814                   1,10
9     Puerto Nuevo        1832           1561                   1,17

Comments:
1. The highest ratios are found in Santiago and Puerto Nuevo
*/
