RUNDEF Section21

/*
CALCULATING THE DEPENDENCY RATIO BASED ON AGE GROUPS

Program description:
The program calculates the dependency ratio indicator by area. 
The dependency ratio of a given area is defined as the ratio of dependants
(children and elders) by the independents (adults). The variable PERSON.GRP3
(programmed earlier in Section07) is used for establishing the respective counts.

The program illustrates the production of a list at COUNTY level. 

*/
DEFINE PERSON.GRP3 AS RECODE PERSON.AGE  
    (0 - 14=1)  (15 - 64=2)  (65 - HIGHEST =3)
    RANGE 1 - 3
    VARLABEL "Age groups 3"
    VALUELABELS 1 "Children" 2 "Adults" 3 "Elders"
    
DEFINE COUNTY.DEPEND AS COUNT PERSON
  FOR PERSON.GRP3 <> 2
  VARLABEL "# of Dependents"

DEFINE COUNTY.INDEP AS COUNT PERSON
  FOR PERSON.GRP3 = 2
  VARLABEL "# of Actives"

DEFINE COUNTY.DEPRATIO AS 100 * (COUNTY.DEPEND / COUNTY.INDEP)
  TYPE REAL
  FOR COUNTY.INDEP > 0
  VARLABEL "Dependency Ratio"
  DECIMALS 2
  
TABLE VERIF AS AREALIST OF COUNTY, COUNTY.NCOUNTY,
  COUNTY.DEPEND, COUNTY.INDEP, COUNTY.DEPRATIO
  TITLE "Dependency Ratio in New Miranda"
  DECIMALS 2

/*
Programming notes:
1. Everytime we use a division operation we need to:
	1.1 define the variable as type real
	1.2 check to prevent a division by 0.

Results:
Code County Name  # of Dependents   # of Actives   Dependency Ratio
5    Santa Maria             8293          13435              61,73
6    Santiago                4191           4778              87,71
7    Bolivar                 6053           8228              73,57
8    Marbella                1455           2363              61,57
9    Puerto Nuevo            1311           2082              62,97

Comments:
1. The worst county in terms of dependency ratio is Santiago.
*/
