RUNDEF Section22

/*
NOT APPLICABLE VALUES

Program description:
This section illustrates the concept of Not Applicable value. 
A non-applicable value reflects the non-existence of the definition
of a concept (variable) for an entity.

This program runs different calculations of the same variable
in order to demonstrate how to control the non-applicable value.

*/

//Case 1
DEFINE PERSON.WFERT1 AS PERSON.SEX = 2 AND PERSON.AGE > 14
  TYPE BOOL
  VARLABEL "Females over fertile age 1"
  
TABLE VERIF1 AS FREQUENCY OF PERSON.WFERT1

/*
Results:
Categories  Counts
 False       35345
 True        16844
 Total       52189

Comments:
1. The calculation of PERSON.WFERT1 considers the entire population. 
2. The category False includes males as well as females under 15.
*/

//Case 2
DEFINE PERSON.WFERT2 AS 1
  FOR PERSON.SEX = 2 AND PERSON.AGE > 14
  TYPE BOOL
  VARLABEL "Females over fertile age 2"
  
TABLE VERIF2 AS FREQUENCY OF PERSON.WFERT2

/*
Results:
Categories  Counts
 True        16844
 Total       16844

NotApp :     35345

Comments:
1. The calculation of PERSON.WFERT2 considers only female over fertile age. 
2. All other individuals are not considered in the calculation (clause FOR)
   and go to a non-applicable value. Only one category (True) is tabulated.
   The other category is at the bottom, in the notapplicable line.
*/

//Case 3
DEFINE PERSON.WFERT3 AS PERSON.AGE > 14
  FOR PERSON.SEX = 2
  TYPE BOOL
  VARLABEL "Females over fertile age 3"
  
TABLE VERIF3 AS FREQUENCY OF PERSON.WFERT3

/*
Results:
Categories  Counts
 False        8511
 True        16844
 Total       25355

NotApp :     26834

Comments:
1. The calculation of PERSON.WFERT3 considers only female individuals. 
2. All males have a non-applicable value. Category False includes females under 15.
*/

//Case 4
DEFINE PERSON.WFERT4 AS PERSON.AGE > 14
  FOR PERSON.SEX = 2
  VARLABEL "Females over fertile age 4"
  DEFAULT 2
  VALUELABELS 1 "True" 0 "False" 2 "Males"
  RANGE 0-2
  
TABLE VERIF4 AS FREQUENCY OF PERSON.WFERT4

/*
Results:
Categories   Counts
 False         8511
 True         16844
 Males        26834
 Total        52189

Comments:
1. The calculation of PERSON.WFERT4 considers only females,
   however forces a category 2 for unconsidered cases (males).
   Thus, the males are included in the tabulation (note the DEFAULT 2
   as well as the RANGE 0-2).
2. In this case we cannot use a BOOL variable.
3. This is better than PERSON.WFERT1 since it has all possible combinations,
   female under 15, female over 14, and males.
*/
