RUNDEF Section23

/*
MISSING VALUES

Program description:
A missing value is an invalid value, i.e. out of the specified range.
The variable does exist for the case, i.e. it should be defined, but for some reason,
it is not an acceptable value for the database.
A non-applicable value reflects the non-existence of the variable.
A missing value reflects an illegal value for the variable. 
*/

//Same as in Section22
DEFINE PERSON.WFERT4 AS PERSON.AGE > 14
  FOR PERSON.SEX = 2
  VARLABEL "Females over fertile age 4"
  DEFAULT 2
  VALUELABELS 1 "True" 0 "False" 2 "Males"
  RANGE 0-2

TABLE VERIF4 AS FREQUENCY OF PERSON.WFERT4   
  
/*
Results:
Categories   Counts
 False         8511
 True         16844
 Males        26834
 Total        52189

Comments:
1. The calculation of PERSON.WFERT4 considers only females,
   however forces a category 2 for unconsidered cases (males).
   Thus, the males are included in the tabulation (note the DEFAULT 2
   as well as the RANGE 0-2).
   In this case we cannot use a BOOL variable.
2. This is better than PERSON.WFERT1 since it has all possible combinations,
   female under 15, female over 14, and males.
*/  

DEFINE PERSON.WFERT5 AS PERSON.AGE > 14
  FOR PERSON.SEX = 2
  VARLABEL "Females over fertile age 5"
  DEFAULT 2
  VALUELABELS 1 "True" 0 "False"
  RANGE 0-1

TABLE VERIF5 AS FREQUENCY OF PERSON.WFERT4, PERSON.WFERT5

/*
Programming notes:
1. The calculation is identical, the only difference appears in the RANGE clause.
   The missing value is introduced in WFERT5 by reducing the range of the variable. 
2. In both cases, the variable exists. In the second case the variable has been
   set artificially out of range.

Results:
Categories   Counts
 No            8511
 Yes          16844
 Total        25355
 
Missing :     26834

Comments:
1. Only the female population has been considered. 
2. All males should have a non-applicable value. 
3. The clause DEFAULT 2 should reintegrate the males in the variable categories. 
   However, the RANGE 0-1 excludes the males because of an illegal value,
   thus setting the variable with a missing value. 
*/
